Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BatchProcessor ¶
BatchProcessor defines an interface for processing individual jobs. Implementers of this interface provide the logic for processing each job and returning the results.
type Job ¶
type Job struct {
Ctx context.Context // Context associated with the job, allowing for cancellation, timeout, etc.
ID string // Unique identifier for the job.
Payload interface{} // Content or data of the job for processing.
}
Job represents a unit of work to be processed
type JobResult ¶
type JobResult struct {
JobID string // Identifier for the processed job.
BatchNumber int64 // Batch in which the job was processed.
Output interface{} // Result from processing the job.
Err error // Any error encountered during processing.
}
JobResult captures the result of processing a Job
Click to show internal directories.
Click to hide internal directories.